==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/SectionHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { SectionHeaderDescription } from "./SectionHeaderDescription";
/**
 * @hidden
 */
var SectionHeaderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SectionHeaderDescriptionMetadata, _super);
    function SectionHeaderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SectionHeaderDescriptionMetadata.b = function (a) {
        if (SectionHeaderDescriptionMetadata.a == null) {
            SectionHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SectionHeaderDescriptionMetadata.c(SectionHeaderDescriptionMetadata.a);
        }
        if (a.g(SectionHeaderDescriptionMetadata.a)) {
            return;
        }
        a.s(SectionHeaderDescriptionMetadata.a);
    };
    SectionHeaderDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
        a.item("SelectedBackground", "Brush");
        a.item("ActualSelectedBackground", "Brush");
        a.item("PaddingLeft", "Number:int");
        a.item("PaddingTop", "Number:int");
        a.item("PaddingRight", "Number:int");
        a.item("PaddingBottom", "Number:int");
        a.item("IsCollapsable", "Boolean");
        a.item("SummaryDisplayMode", "ExportedType:string:GroupSummaryDisplayMode");
        a.item("SummaryDisplayMode@names", "List;Cells;RowTop;RowBottom;None");
    };
    SectionHeaderDescriptionMetadata.d = function (a) {
        SectionHeaderDescriptionMetadata.b(a);
        a.u("SectionHeader", function () { return new SectionHeaderDescription(); });
        a.t("SectionHeader", SectionHeaderDescriptionMetadata.a);
    };
    SectionHeaderDescriptionMetadata.$t = markType(SectionHeaderDescriptionMetadata, 'SectionHeaderDescriptionMetadata');
    SectionHeaderDescriptionMetadata.a = null;
    return SectionHeaderDescriptionMetadata;
}(Base));
export { SectionHeaderDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/SectionHeaderDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { DefinitionBaseDescriptionMetadata } from "./DefinitionBaseDescriptionMetadata";
import { SectionHeaderDescription } from "./SectionHeaderDescription";
/**
 * @hidden
 */
var SectionHeaderDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(SectionHeaderDescriptionMetadata, _super);
    function SectionHeaderDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SectionHeaderDescriptionMetadata.b = function (a) {
        if (SectionHeaderDescriptionMetadata.a == null) {
            SectionHeaderDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            SectionHeaderDescriptionMetadata.c(SectionHeaderDescriptionMetadata.a);
        }
        if (a.j(SectionHeaderDescriptionMetadata.a)) {
            return;
        }
        a.y(SectionHeaderDescriptionMetadata.a);
    };
    SectionHeaderDescriptionMetadata.c = function (a) {
        DefinitionBaseDescriptionMetadata.c(a);
        a.item("SelectedBackground", "Brush");
        a.item("ActualSelectedBackground", "Brush");
        a.item("PaddingLeft", "Number:int");
        a.item("PaddingTop", "Number:int");
        a.item("PaddingRight", "Number:int");
        a.item("PaddingBottom", "Number:int");
        a.item("IsCollapsable", "Boolean");
        a.item("SummaryDisplayMode", "ExportedType:string:GroupSummaryDisplayMode");
        a.item("SummaryDisplayMode@names", "List;Cells;RowTop;RowBottom;None");
    };
    SectionHeaderDescriptionMetadata.d = function (a) {
        SectionHeaderDescriptionMetadata.b(a);
        a.aa("SectionHeader", function () { return new SectionHeaderDescription(); });
        a.z("SectionHeader", SectionHeaderDescriptionMetadata.a);
    };
    SectionHeaderDescriptionMetadata.$t = markType(SectionHeaderDescriptionMetadata, 'SectionHeaderDescriptionMetadata');
    SectionHeaderDescriptionMetadata.a = null;
    return SectionHeaderDescriptionMetadata;
}(Base));
export { SectionHeaderDescriptionMetadata };
